==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/Modules/gamepad/GamepadEvent.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef GamepadEvent_h
#define GamepadEvent_h

#if ENABLE(GAMEPAD)

#include "Event.h"
#include "Gamepad.h"
#include <wtf/RefPtr.h>

namespace WebCore {

struct GamepadEventInit : public EventInit {
    GamepadEventInit()
    {
    }

    RefPtr<Gamepad> gamepad;
};

class GamepadEvent : public Event {
public:
    ~GamepadEvent() { }

    static PassRefPtr<GamepadEvent> create()
    {
        return adoptRef(new GamepadEvent);
    }

    static PassRefPtr<GamepadEvent> create(const AtomicString& eventType, Gamepad& gamepad)
    {
        return adoptRef(new GamepadEvent(eventType, gamepad));
    }

    static PassRefPtr<GamepadEvent> create(const AtomicString& eventType, const GamepadEventInit& initializer)
    {
        return adoptRef(new GamepadEvent(eventType, initializer));
    }

    Gamepad* gamepad() const { return m_gamepad.get(); }

    virtual EventInterface eventInterface() const override { return GamepadEventInterfaceType; }

private:
    GamepadEvent();
    explicit GamepadEvent(const AtomicString& eventType, Gamepad&);
    GamepadEvent(const AtomicString& eventType, const GamepadEventInit&);

    RefPtr<Gamepad> m_gamepad;
};

} // namespace WebCore

#endif // ENABLE(GAMEPAD)
#endif // GamepadEvent_h

==> webkitgtk-2.14.0.tar.xz: webkitgtk-2.14.0/Source/WebCore/Modules/gamepad/GamepadEvent.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef GamepadEvent_h
#define GamepadEvent_h

#if ENABLE(GAMEPAD)

#include "Event.h"
#include "Gamepad.h"
#include <wtf/RefPtr.h>

namespace WebCore {

struct GamepadEventInit : public EventInit {
    RefPtr<Gamepad> gamepad;
};

class GamepadEvent : public Event {
public:
    ~GamepadEvent() { }

    static Ref<GamepadEvent> create(const AtomicString& eventType, Gamepad& gamepad)
    {
        return adoptRef(*new GamepadEvent(eventType, gamepad));
    }

    static Ref<GamepadEvent> createForBindings(const AtomicString& eventType, const GamepadEventInit& initializer)
    {
        return adoptRef(*new GamepadEvent(eventType, initializer));
    }

    Gamepad* gamepad() const { return m_gamepad.get(); }

    EventInterface eventInterface() const override { return GamepadEventInterfaceType; }

private:
    explicit GamepadEvent(const AtomicString& eventType, Gamepad&);
    GamepadEvent(const AtomicString& eventType, const GamepadEventInit&);

    RefPtr<Gamepad> m_gamepad;
};

} // namespace WebCore

#endif // ENABLE(GAMEPAD)
#endif // GamepadEvent_h
